// ignore_for_file: constant_identifier_names

import 'package:flutter/material.dart';
import 'package:flutter/widgets.dart';
import 'package:karot_components/button/karot_button.dart';
import 'package:karot_components/button/karot_text_button.dart';
import 'package:karot_components/constant/button_enum.dart';
import 'package:karot_components/constant/text_enum.dart';
import 'package:karot_components/constant/theme.dart';
import 'package:karot_components/label/karot_label.dart';
import 'package:karot_components/label/karot_note.dart';
import 'package:lottie/lottie.dart';

import '../karot_ultilities.dart';

class KRCardDialog extends StatelessWidget {
  final String? assetURL;
  final String title;
  final String bodyText;
  final int backgroundColor;
  final int textColor;
  final VoidCallback onDismissTap;
  final VoidCallback? onConfirmTap;
  final String? confirmText;
  final String dismissText;

  const KRCardDialog({
    Key? key,
    this.assetURL,
    required this.onDismissTap,
    required this.title,
    required this.bodyText,
    this.onConfirmTap,
    this.confirmText,
    this.dismissText = "Cancel",
    this.backgroundColor = KRTheme.DEFAULT_LIGHT_COLOR,
    this.textColor = KRTheme.DEFAULT_DARK_COLOR,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Column(
      mainAxisSize: MainAxisSize.min,
      children: [
        assetURL != null ? Lottie.asset(assetURL ?? "", width: 150, height: 150, repeat: false) : const SizedBox(),
        KRLabel(text: title, isBold: true, size: KRTextSize.title),
        KRNote(
            text: bodyText, textAlign: TextAlign.center, size: KRTextSize.body),
        const KRGap(height: 40),
        actionButtons(context)
      ],
    );
  }

  Widget actionButtons(BuildContext context) {
    if (onConfirmTap != null) {
      return Row(mainAxisAlignment: MainAxisAlignment.spaceAround, children: [
        KRTextButton(
            text: dismissText,
            isBold: false,
            textColor: KRTheme.DEFAULT_GREY_COLOR,
            size: KRButtonSize.large,
            onPress: () {
              Navigator.of(context).pop();
              onDismissTap.call();
            }),
        KRButton(
            text: confirmText ?? "",
            isFull: false,
            isOutline: false,
            isBold: false,
            size: KRButtonSize.large,
            onPress: () {
              Navigator.of(context).pop();
              onConfirmTap?.call();
            }),
      ]);
    } else {
      return KRButton(
          text: dismissText,
          isFull: true,
          isOutline: false,
          isBold: false,
          size: KRButtonSize.large,
          onPress: () {
            Navigator.of(context).pop();
            onDismissTap.call();
          });
    }
  }
}
