// ignore_for_file: constant_identifier_names

import 'package:flutter/material.dart';
import 'package:flutter/widgets.dart';
import 'package:karot_components/button/karot_text_button.dart';
import 'package:karot_components/constant/button_enum.dart';
import 'package:karot_components/constant/text_enum.dart';
import 'package:karot_components/constant/theme.dart';
import 'package:karot_components/label/karot_label.dart';

class KRCardPrimary extends StatelessWidget {
  final String title;
  final String subtitle;
  final Widget child;
  final EdgeInsetsGeometry padding;
  final int backgroundColor;
  final List<Color>? gradientColor;
  final int headerColor;
  final int textColor;

  const KRCardPrimary({
    Key? key,
    required this.title,
    required this.subtitle,
    required this.child,
    this.gradientColor,
    this.padding = const EdgeInsets.all(KRTheme.PADDING_NORMAL),
    this.backgroundColor = KRTheme.DEFAULT_LIGHT_COLOR,
    this.headerColor = KRTheme.DEFAULT_SECONDARY_COLOR,
    this.textColor = KRTheme.DEFAULT_DARK_COLOR,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Stack(
      children: [
        Container(
          height: 200,
          width: MediaQuery.of(context).size.width,
          decoration: box(headerColor),
          child: Column(
            mainAxisAlignment: MainAxisAlignment.start,
            children: [
              Row(mainAxisAlignment: MainAxisAlignment.spaceBetween, children: [
                KRLabel(
                    padding: const EdgeInsets.only(left: 20, bottom: 30),
                    text: title,
                    isBold: true,
                    textColor: KRTheme.DEFAULT_DARK_COLOR,
                    size: KRTextSize.subtitle,
                    textAlign: TextAlign.left),
                ClipRRect(
                  borderRadius:
                      const BorderRadius.only(topRight: Radius.circular(20)),
                  child: Image.asset(
                      'packages/karot_components/assets/header_image.png',
                      width: 150),
                ),
              ]),
            ],
          ),
        ),
        Container(
            width: MediaQuery.of(context).size.width,
            padding: padding,
            margin: const EdgeInsets.only(top: 60),
            decoration: boxShadow(backgroundColor),
            child: Column(
              mainAxisSize: MainAxisSize.min,
              children: [
                Row(
                  mainAxisAlignment: MainAxisAlignment.spaceBetween,
                  children: [
                    KRLabel(
                        padding: const EdgeInsets.only(left: 10),
                        text: subtitle,
                        isBold: true,
                        size: KRTextSize.body,
                        textAlign: TextAlign.left),
                    KRTextButton(
                        text: "View ", size: KRButtonSize.small, onPress: () {})
                  ],
                ),
                child
              ],
            ))
      ],
    );
  }

  BoxDecoration boxShadow(int backgroundColor) {
    return BoxDecoration(boxShadow: [
      BoxShadow(
        color: Colors.grey.withOpacity(0.1),
        spreadRadius: 5,
        blurRadius: 5,
        offset: const Offset(0, 0), // changes position of shadow
      ),
    ], color: Color(backgroundColor), borderRadius: BorderRadius.circular(20));
  }

  BoxDecoration box(int backgroundColor) {
    return BoxDecoration(
        gradient: gradientColor != null ? LinearGradient(
            begin: Alignment.centerLeft,
            end: Alignment.centerRight,
            colors: gradientColor!) : null,
        color: Color(backgroundColor),
        borderRadius: BorderRadius.circular(20));
  }
}
