// ignore_for_file: prefer_const_constructors_in_immutables

import 'package:flutter/material.dart';

class KRSlider extends StatefulWidget {
  final double radius;
  final double height;
  final double width;
  final Color backgroundColor;
  final Color baseColor;
  final Color highlightedColor;
  final Color buttonColor;
  final Widget label;
  final Alignment alignLabel;
  final IconData? icon;
  final VoidCallback? action;
  final bool dismissible;
  final bool vibrationFlag;
  final double dismissThresholds;

  final bool disable;

  KRSlider({
    Key? key,
    this.action,
    this.radius = 100,
    this.vibrationFlag = false,
    this.height = 45,
    this.width = 200,
    this.alignLabel = const Alignment(0, 0),
    this.backgroundColor = const Color(0xffe0e0e0),
    this.baseColor = Colors.black87,
    this.buttonColor = Colors.white,
    this.highlightedColor = Colors.white,
    required this.label,
    this.icon,
    this.dismissible = true,
    this.dismissThresholds = 1.0,
    this.disable = false,
  }) : super(key: key);

  @override
  _SliderButtonState createState() => _SliderButtonState();
}

class _SliderButtonState extends State<KRSlider> {
  late bool flag;

  @override
  void initState() {
    super.initState();
    flag = true;
  }

  @override
  Widget build(BuildContext context) {
    return flag == true
        ? _control()
        : widget.dismissible == true
            ? Container()
            : Container(
                child: _control(),
              );
  }

  Widget _control() => Container(
        height: widget.height,
        width: widget.width,
        decoration: BoxDecoration(
          color: widget.disable ? Colors.grey.shade700 : widget.backgroundColor,
          borderRadius: BorderRadius.circular(widget.radius),
        ),
        child: Stack(
          alignment: Alignment.centerLeft,
          children: <Widget>[
            Row(
              crossAxisAlignment: CrossAxisAlignment.center,
              mainAxisAlignment: MainAxisAlignment.spaceAround,
              children: [
                const SizedBox(width: 50),
                widget.label,
              ],
            ),
            Dismissible(
              key: const Key("cancel"),
              direction: DismissDirection.startToEnd,
              dismissThresholds: {
                DismissDirection.startToEnd: widget.dismissThresholds
              },
              confirmDismiss: (direction) async {
                widget.action?.call();
                return false;
              },
              child: Container(
                width: widget.width / 2,
                height: widget.height,
                alignment: Alignment.centerLeft,
                child: Container(
                  height: widget.height,
                  width: widget.width / 2,
                  decoration: BoxDecoration(
                      boxShadow: [
                        BoxShadow(
                          color: Colors.grey.withOpacity(0.1),
                          spreadRadius: 3,
                          blurRadius: 3,
                          offset: const Offset(0, 0), // changes position of shadow
                        ),
                      ],
                      color: widget.buttonColor,
                      borderRadius: BorderRadius.circular(100)),
                  child: const Center(child: Icon(Icons.arrow_forward)),
                ),
              ),
            ),
          ],
        ),
      );
}
